Class: BaseController

Inherits:
ApplicationController show all
Defined in:
app/controllers/base_controller.rb

Instance Method Summary collapse

Instance Method Details

#buttonsObject



13
14
15
16
# File 'app/controllers/base_controller.rb', line 13

def buttons
  @page_title = "Base <small>Buttons</small>"
  @page_nav = base_nav
end

#formsObject



23
24
25
26
# File 'app/controllers/base_controller.rb', line 23

def forms
  @page_title = "Base <small>Forms</small>"
  @page_nav = base_nav
end

#imagesObject



28
29
30
31
# File 'app/controllers/base_controller.rb', line 28

def images
  @page_title = "Base <small>Images</small>"
  @page_nav = base_nav
end

#indexObject



2
3
4
5
6
# File 'app/controllers/base_controller.rb', line 2

def index
  @page_title = "Base <small>type</small>"
  @page_description = "Arguably the most important section of the style guide, where the foundations of the site are set. All modules will be extended from these base styles."
  @page_nav = base_nav
end

#labelsObject



18
19
20
21
# File 'app/controllers/base_controller.rb', line 18

def labels
  @page_title = "Base <small>Labels</small>"
  @page_nav = base_nav
end

#listsObject



8
9
10
11
# File 'app/controllers/base_controller.rb', line 8

def lists
  @page_title = "Base <small>lists</small>"
  @page_nav = base_nav
end

#webfontsObject



33
34
35
36
37
# File 'app/controllers/base_controller.rb', line 33

def webfonts
  @page_title = "Base <small>Web Fonts</small>"
  @page_description = "These are the web fonts that we have at our disposal. When using these fonts you should be certain they are neccessary, when you use just 1 character the user must downloaded the full font."
  @page_nav = base_nav
end